vip\_hci.var package
====================

Submodules
----------

vip\_hci.var.coords module
--------------------------

.. automodule:: vip_hci.var.coords
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.var.filters module
---------------------------

.. automodule:: vip_hci.var.filters
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.var.fit\_2d module
---------------------------

.. automodule:: vip_hci.var.fit_2d
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.var.iuwt module
------------------------

.. automodule:: vip_hci.var.iuwt
   :members:
   :undoc-members:
   :show-inheritance:

vip\_hci.var.shapes module
--------------------------

.. automodule:: vip_hci.var.shapes
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: vip_hci.var
   :members:
   :undoc-members:
   :show-inheritance:
